@@ -6,7 +6,7 @@
    Class declaration for a sample output driver with no additional attributes
    and methods (minimal interface)
 
-   Copyright (C) 1993 - 2003 Wolfgang Glunz, wglunz@pstoedit.net
+   Copyright (C) 1993 - 2005 Wolfgang Glunz, wglunz34_AT_pstoedit.net
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -34,6 +34,15 @@ public:
 	//(const char * driveroptions_P,ostream & theoutStream,ostream & theerrStream ); // Constructor
 
 	~drvJAVA(); // Destructor
+	class DriverOptions : public ProgramOptions { 
+	public:
+		Option < RSString, RSStringValueExtractor> jClassName;
+		DriverOptions():
+			jClassName(true,"java class name","string",0,"name of java class to generate",0,(const char *)"PSJava")
+		{
+			ADD(jClassName);
+		}
+	}*options;
 
 #include "drvfuncs.h"
 	void show_text(const TextInfo & textInfo);
@@ -46,4 +55,3 @@ private:
 
 #endif
  
- 
