@@ -70,80 +70,164 @@ const int PLACEABLESIZE = 22;
 // regarding alignment (Wo Gl)
 #pragma pack(2)
 struct PLACEABLEHEADER {
-	DWORD key;
+	DWORD32 key;
 	WORD hmf;
 	WORD left;
 	WORD top;
 	WORD right;
 	WORD bottom;
 	WORD inch;
-	DWORD reserved;
+	DWORD32 reserved;
 	WORD checksum;
 };
 
 static const char description[] = "generated by WMF/EMF backend of pstoedit\0input\0\0";
 
+
+inline float drvWMF::scale() const
+{
+	const float scalef =  20.0f;
+	if (options->OpenOfficeMode)
+		return 1.0f;
+	else
+		return scalef;
+}
+
+
+inline long drvWMF::transx(float x) const
+{
+	if (options->OpenOfficeMode)
+		return l_transX(x);
+	else
+		return (long)(scale() * (x));
+}
+
+inline long drvWMF::transy(float y) const
+{
+	if (options->OpenOfficeMode)
+		return l_transY(y);
+	else
+		return (long)(scale() * (currentDeviceHeight - y));
+}
+
+void drvWMF::initMetaDC(HDC hdc){
+
+
+#ifdef OLDCODE
+// temporary - testing
+			// set bounding box
+//          SetWindowOrgEx(hdc, minX, minY, NIL);
+			SetWindowOrgEx(hdc, minX, maxY, NIL);
+
+//			SetViewportOrgEx(hdc, 0, 0, NIL);
+
+			SetWindowExtEx(hdc, maxX - minX, maxY - minY, NIL);
+			SetViewportExtEx(hdc, maxX - minX, maxY - minY, NIL);
+//          SetViewportExtEx(hdc,
+//                           (long)((float)(maxX - minX) * (float)GetDeviceCaps(desktopDC,HORZRES) / 
+//                                  (float)GetDeviceCaps(desktopDC,HORZSIZE) + .5),
+//                           (long)((float)(maxY - minY) * (float)GetDeviceCaps(desktopDC,VERTRES) /
+//                                  (float)GetDeviceCaps(desktopDC,VERTSIZE) + .5), NIL);
+
+#else
+		
+			// set reasonable mapping mode (don't want distortion)
+			//SetMapMode(hdc, MM_ISOTROPIC);
+			SetMapMode(hdc, MM_ANISOTROPIC);
+
+
+	if (!options->OpenOfficeMode) {
+		if (1){
+			const int result = SetMapMode(hdc, MM_ANISOTROPIC);
+			assert(result != 0);
+		}
+		SIZE oldWinExt;
+		{
+			const BOOL result = SetWindowExtEx(hdc, 1440, 1440, &oldWinExt);
+//      const BOOL result = SetWindowExtEx(pd->hdcEMF,144,144,&oldWinExt);
+			assert(result != 0);
+		}
+		SIZE oldViewPortExt;
+		{
+			const int result = SetViewportExtEx(hdc,
+												GetDeviceCaps(metaDC, LOGPIXELSX),
+												GetDeviceCaps(metaDC, LOGPIXELSY),
+												&oldViewPortExt);
+			assert(result != 0);
+		}
+	}
+#endif
+
+
+}
+
 drvWMF::derivedConstructor(drvWMF):
 constructBase, enhanced(false)
- //drawBoundingBox(true), narrowbox(true)
 {
 	// do some consistency checking
-	if (sizeof(PLACEABLEHEADER) != PLACEABLESIZE) {
+	if (! ( (sizeof(PLACEABLEHEADER) == PLACEABLESIZE) || (sizeof(PLACEABLEHEADER) == (PLACEABLESIZE+2)) ) ) {
 		errf <<
 			"WARNING: structure size mismatch. Please contact author. Expecting :"
 			<< PLACEABLESIZE << " found " << sizeof(PLACEABLEHEADER) << endl;
 		errf << "sizeof(WORD)    = " << sizeof(WORD) << endl;	// MSVC:  2
-		errf << "sizeof(DWORD)   = " << sizeof(DWORD) << endl;	// MSVC:  4
+		errf << "sizeof(DWORD32)   = " << sizeof(DWORD32) << endl;	// MSVC:  4
 		errf << "sizeof(RECT)    = " << sizeof(RECT) << endl;	// MSVC: 16
 		errf << "sizeof(HANDLE)  = " << sizeof(HANDLE) << endl;	// MSVC:  4
-		ctorOK = false;
-		return;
+ 		ctorOK = false;
+ 		return;
+		// now the write below writes PLACEABLESIZE and no longer sizeof(PLACEABLEHEADER)
+		// this should be independent then of the packing
+		// the 2 bytes saved are those at the end of the struct
 	}
 
-	desktopDC = GetDC(GetDesktopWindow());
+	// desktopDC = GetDC(GetDesktopWindow());
+
+	if (options->OpenOfficeMode) {
+		desktopDC = GetDC(GetDesktopWindow());
+	} else {
+		desktopDC = NIL;
+	}
 
 	// which output format?
 	if (strcmp(Pdriverdesc->symbolicname, "emf") == 0) {
 		enhanced = true;
 	}
-#if 0
-	// any driver options?
-	if (driveroptions_p != NIL) {
-		// map everything to arial?
-		if (strstr(driveroptions_p, "-m") != NIL) {
-			mapToArial = true;
-		}
-		// emulate narrow fonts?
-		if (strstr(driveroptions_p, "-nf") != NIL) {
-			emulateNarrowFonts = true;
-		}
-		if (strstr(driveroptions_p, "-nb") != NIL) {
-			narrowbox = false;
-		}
-		// shall we switch off drawing of bounding box?
-		if (strstr(driveroptions_p, "-b") != NIL) {
-			drawBoundingBox = false;
-		}
-		// shall we prune lineends (#) from text output?
-		if (strstr(driveroptions_p, "-l") != NIL) {
-			pruneLineEnds = true;
-		}
-	}
-#endif
 
 	if (enhanced) {
+#if 1
+		const BBox & psBBox = getCurrentBBox();
+
+		minX = transx(psBBox.ll.x_);
+		minY = transy(psBBox.ur.y_);
+		maxX = transx(psBBox.ur.x_);
+		maxY = transy(psBBox.ll.y_);
+
+//		const RECT bbox = { minX, minY, maxX, maxY };
+		if (Verbose()) errf << "calculated Bounding Box: " << minX << " " << minY << " " << maxX << " " << maxY << endl;
+		// cout << "PostScript Bounding Box: " << psBBox.ll.x_  << " " << psBBox.ll.y_ << " " << psBBox.ur.x_ << " " << psBBox.ur.y_ << endl;
+#endif
+
+		// 
 		// enhanced-Metafile (memory based) for W95/98 or NT
-		if (options->narrowbox) {
+		// if -nb is set, then narrowbox = false , -nb means no bounding box 
+		if (options->winbb) {
+			if (Verbose()) errf << " Windows will calculate BB " << endl;
 			metaDC = CreateEnhMetaFile(desktopDC, NIL, NIL, NIL);
 		} else {
 	// under non Windows systems we cannot use PlayEnhMetafile
+			if (Verbose()) errf << " not creating with bounding box " << endl;
+			// metaDC = CreateEnhMetaFile(desktopDC, outFileName.value(), &bbox , description);
 			metaDC = CreateEnhMetaFile(desktopDC, outFileName.value(), NIL, description);
 		}
+
 		if (!metaDC) {
-			errf << "ERROR: could create enhanced metafile" << endl;
+			errf << "ERROR: could not create enhanced metafile" << endl;
 			ctorOK = false;
 			return;
-		}
+		} 
+		
+		initMetaDC(metaDC);
+
 	} else {
 		// take temp file for standard WMF, to prepend placeable header
 		tempName = full_qualified_tempnam("wmftemp");
@@ -207,9 +291,39 @@ constructBase, enhanced(false)
 	SetTextAlign(metaDC, TA_BASELINE);
 }
 
+static void writeErrorCause(const char * mess)  
+{
+#ifdef _WIN32
+	DWORD ec = GetLastError(); 
+	LPVOID lpMsgBuf; 
+	FormatMessage( 
+		FORMAT_MESSAGE_ALLOCATE_BUFFER | FORMAT_MESSAGE_FROM_SYSTEM, 
+		NULL, 
+		ec, 
+		MAKELANGID(LANG_NEUTRAL, SUBLANG_DEFAULT), 
+		(LPTSTR) &lpMsgBuf,	
+		0,	
+		NULL	
+	);	
+	cerr << "Error Code for "  << mess << " ec: " << ec << " " << (char*) lpMsgBuf << endl; 
+	LocalFree( lpMsgBuf ); 
+#endif
+}
+
 
 drvWMF::~drvWMF()
 {
+	const BBox & psBBox = getCurrentBBox();
+
+	minX = transx(psBBox.ll.x_);
+	minY = transy(psBBox.ur.y_);
+	maxX = transx(psBBox.ur.x_);
+	maxY = transy(psBBox.ll.y_);
+
+	if (Verbose()) errf << "original PostScript Bounding Box   : " << psBBox.ll.x_  << " " << psBBox.ll.y_ << " " << psBBox.ur.x_ << " " << psBBox.ur.y_ << endl;
+	if (Verbose()) errf << "transformed PostScript Bounding Box: " << minX << " " << minY << " " << maxX << " " << maxY << endl;
+
+
 	// is the output within signed integer boundaries?
 	if (minX < -20000 ||
 		minX > 20000 ||
@@ -225,8 +339,14 @@ drvWMF::~drvWMF()
 	if (options->drawBoundingBox) {
 		// standard metafile does not care much about user space.
 		// so we have to draw two white dummy points at the pic's boundaries
-		SetPixel(metaDC, minX, minY, RGB(255, 255, 255));
-		SetPixel(metaDC, maxX, maxY, RGB(255, 255, 255));
+		if (Verbose()) {
+			// in verbose mode use a non with pixel
+			SetPixel(metaDC, minX, minY, RGB(0, 120, 0));
+			SetPixel(metaDC, maxX, maxY, RGB(0, 120, 120));
+		} else {
+			SetPixel(metaDC, minX, minY, RGB(255, 255, 255));
+			SetPixel(metaDC, maxX, maxY, RGB(255, 255, 255));
+		}
 	}
 	// free any allocated objects
 	if (coloredPen) {
@@ -279,41 +399,36 @@ drvWMF::~drvWMF()
 
 		// create our final metafile (metaDC is reused)
 		// need to have two metafiles, because we know the output dimension just now
-		if (options->narrowbox) {
+		if (options->winbb) {
+			// const RECT bbox = { minX, minY, maxX, maxY };
+			if (Verbose()) cout << "creating final metafile" << endl;
+			// cout << "creating with bounding box 2: " << minX << "," << minY<< "," << maxX<< "," << maxY << endl;
+			// don't need a BB here - Windows will calculate it by itself (that is the whole purpose of the later replay)
 			metaDC = CreateEnhMetaFile(desktopDC, outFileName.value(), NIL, description);
+			initMetaDC(metaDC);
 		}
 		if (metaDC) {
-			// set reasonable mapping mode (don't want distortion)
-			SetMapMode(metaDC, MM_ISOTROPIC);
 
-			// set bounding box
-//          SetWindowOrgEx(metaDC, minX, minY, NIL);
-			SetWindowOrgEx(metaDC, minX, maxY, NIL);
-			SetViewportOrgEx(metaDC, 0, 0, NIL);
-
-			SetWindowExtEx(metaDC, maxX - minX, maxY - minY, NIL);
-			SetViewportExtEx(metaDC, maxX - minX, maxY - minY, NIL);
-//          SetViewportExtEx(metaDC,
-//                           (long)((float)(maxX - minX) * (float)GetDeviceCaps(desktopDC,HORZRES) / 
-//                                  (float)GetDeviceCaps(desktopDC,HORZSIZE) + .5),
-//                           (long)((float)(maxY - minY) * (float)GetDeviceCaps(desktopDC,VERTRES) /
-//                                  (float)GetDeviceCaps(desktopDC,VERTSIZE) + .5), NIL);
-
-			const RECT bbox = { minX, minY, maxX, maxY };
+			if (options->winbb) {
+				const RECT bbox = { minX, minY, maxX, maxY };
 //          const RECT  bbox = {minX, minY, maxX-minX, maxY-minY};
 //          const RECT  bbox = {minX, maxY, maxX-minX, maxY-minY};
 //          const RECT  bbox = {minX, maxY, maxX+2*minX, -minY-maxY};
 
-			if (options->narrowbox) {
-			// replay recorded metafile
+			// replay recorded metafile (hMeta -> metaDC)
+				if (Verbose()) errf << "Info: replaying hMeta to metaDC with bounding box : " << minX << "," << minY<< "," << maxX<< "," << maxY << endl;
+
 				if (!PlayEnhMetaFile(metaDC, hMeta, &bbox)) {
+					writeErrorCause("PlayEnhMetaFile");
 					errf << "ERROR: cannot replay created metafile" << endl;
+				} else {
+					if (Verbose())	errf << "Info: replayed metafile" << endl;
 				}
 			}
 			// close and commit metafile
 			DeleteEnhMetaFile(CloseEnhMetaFile(metaDC));
 		} else {
-			errf << "ERROR: could not open metafile: " << outFileName << endl;
+			errf << "ERROR: could not open metafile for replay: " << outFileName << endl;
 		}
 
 		DeleteEnhMetaFile(hMeta);
@@ -349,7 +464,7 @@ drvWMF::~drvWMF()
 				pHd.checksum = checksum;
 
 				// write header
-				if (fwrite(&pHd, sizeof(PLACEABLEHEADER), 1, outFile) != 1) {
+				if (fwrite(&pHd, PLACEABLESIZE , 1, outFile) != 1) {
 					errf << "Can't write final metafile" << endl;
 				}
 				// append metafile data
@@ -444,7 +559,7 @@ void drvWMF::setDrawAttr()
 
 int drvWMF::fetchFont(const TextInfo & textinfo, short int textHeight, short int textAngle)
 {
-	theFontRec.lfHeight = -textHeight;
+	theFontRec.lfHeight = -textHeight ;
 	theFontRec.lfWidth = 0;		// optimal fit
 	theFontRec.lfEscapement = textAngle;
 	theFontRec.lfOrientation = textAngle;
@@ -593,11 +708,11 @@ void drvWMF::drawPoly(POINT * aptlPoints, int *aptlNumPts, polyType type)
 		const basedrawingelement & elem = pathElement(n);
 
 		if (elem.getType() != closepath) {
-			aptlPoints[p].x = l_transX(elem.getPoint(0).x_);
-			aptlPoints[p].y = l_transY(elem.getPoint(0).y_);
+			aptlPoints[p].x = transx(elem.getPoint(0).x_);
+			aptlPoints[p].y = transy(elem.getPoint(0).y_);
 		} else {
-			aptlPoints[p].x = l_transX(0);
-			aptlPoints[p].y = l_transY(0);
+			aptlPoints[p].x = transx(0);
+			aptlPoints[p].y = transy(0);
 		}
 
 		if (elem.getType() == moveto || elem.getType() == lineto || elem.getType() == curveto) {
@@ -862,19 +977,20 @@ void drvWMF::show_text(const TextInfo & textinfo)
 							 (BYTE) (textinfo.currentG * 255 + .5),
 							 (BYTE) (textinfo.currentB * 255 + .5)));
 
-	const short int textHeight = (short int) (textinfo.currentFontSize + .5);	// rounded int
+	const short int textHeight = (short int) (textinfo.currentFontSize*scale() + .5) ;	// rounded int
 	const short int textAngle = (short int) (10 * textinfo.currentFontAngle + .5);	// Windows needs 10th of degree
 
 	// any need to change font handle?
 	if (fontchanged())
 		fetchFont(textinfo, textHeight, textAngle);
 
-	const long x1 = l_transX(textinfo.x);
-	const long y1 = l_transY(textinfo.y);
+	const long x1 = transx(textinfo.x);
+	const long y1 = transy(textinfo.y);
 
-	const long x2 = l_transX(textinfo.x_end);
-	const long y2 = l_transY(textinfo.y_end);
+	const long x2 = transx(textinfo.x_end);
+	const long y2 = transy(textinfo.y_end);
 
+	if (Verbose()) cout << "placing text : " << textinfo.thetext << " at " << textinfo.x << "," << textinfo.y<< " in EMF coords: " << x1 << "," << y1 << endl;
 	// calculate bounding box
 	//
 	// NOTE: cannot do that exactly (with ascent and descent height),
@@ -1000,10 +1116,10 @@ void drvWMF::show_rectangle(const float llx, const float lly, const float urx, c
 	// update pen/brush
 	setDrawAttr();
 
-	localRect.left = l_transX(llx);
-	localRect.top = l_transY(lly);
-	localRect.right = l_transX(urx);
-	localRect.bottom = l_transY(ury);
+	localRect.left = transx(llx);
+	localRect.top = transy(lly);
+	localRect.right = transx(urx);
+	localRect.bottom = transy(ury);
 
 	// calculate bounding box
 	//
@@ -1043,7 +1159,7 @@ void drvWMF::show_rectangle(const float llx, const float lly, const float urx, c
 		Polyline(metaDC, (POINT *) & localRect, 2);
 		// but also using a Rectangle isn't correct. 
 	} else {
-		Rectangle(metaDC, l_transX(llx), l_transY(lly), l_transX(urx), l_transY(ury));
+		Rectangle(metaDC, transx(llx), transy(lly), transx(urx), transy(ury));
 	}
 	}
 }
@@ -1068,15 +1184,15 @@ void drvWMF::show_image(const PSImage & image)
 	const long height = abs(i_transY(upperRight.y_) - i_transY(lowerLeft.y_));
 
 	if (Verbose()) {
-		cout << "image.Width:" << image.width << " image.Height: " << image.height << endl;
-		cout << "Width:" << width << " Height: " << height << endl;
+		errf << "image.Width:" << image.width << " image.Height: " << image.height << endl;
+		errf << "Width:" << width << " Height: " << height << endl;
 	}
 	// calculate bounding box
 	//
-	const int xMin = (int) min(l_transX(upperRight.x_), l_transX(lowerLeft.x_));
-	const int xMax = (int) max(l_transX(upperRight.x_), l_transX(lowerLeft.x_));
-	const int yMin = (int) min(l_transY(upperRight.y_), l_transY(lowerLeft.y_));
-	const int yMax = (int) max(l_transY(upperRight.y_), l_transY(lowerLeft.y_));
+	const int xMin = (int) min(transx(upperRight.x_), transx(lowerLeft.x_));
+	const int xMax = (int) max(transx(upperRight.x_), transx(lowerLeft.x_));
+	const int yMin = (int) min(transy(upperRight.y_), transy(lowerLeft.y_));
+	const int yMax = (int) max(transy(upperRight.y_), transy(lowerLeft.y_));
 
 	if (minStatus) {
 		if (xMin < minX)
@@ -1220,8 +1336,8 @@ void drvWMF::show_image(const PSImage & image)
 		bmi.bmiHeader.biClrImportant = 0;
 
 		if (!SetDIBitsToDevice(metaDC,
-							  l_transX(lowerLeft.x_),
-							  l_transY(upperRight.y_),
+							  transx(lowerLeft.x_),
+							  transy(upperRight.y_),
 							  width, height, 0, 0, 0, height, output, &bmi, DIB_RGB_COLORS)) {
 			errf << "ERROR: Cannot draw bitmap" << endl;
 		}
