@@ -2,7 +2,7 @@
    poptions.cpp : This file is part of pstoedit
    program option handling 
 
-   Copyright (C) 1993 - 2003 Wolfgang Glunz, wglunz@pstoedit.net
+   Copyright (C) 1993 - 2005 Wolfgang Glunz, wglunz34_AT_pstoedit.net
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -23,6 +23,9 @@
 
 #include I_string_h
 #include I_stdlib
+#include I_strstream
+
+#include <miscutil.h>
 
 USESTD
 
@@ -40,12 +43,16 @@ bool IntValueExtractor::getvalue(const char *optname, const char *instring, unsi
 		cout << "missing integer argument for " << optname << " option:" << endl;
 		return false;
 	}
-};
+}
 const char *IntValueExtractor::gettypename()
 {
 	return "integer";
 }
 
+unsigned int IntValueExtractor::gettypeID()
+{
+	return int_ty;
+}
 
 
 bool DoubleValueExtractor::getvalue(const char *optname, const char *instring, unsigned int &currentarg,
@@ -59,12 +66,16 @@ bool DoubleValueExtractor::getvalue(const char *optname, const char *instring, u
 		cout << "missing double argument for " << optname << " option:" << endl;
 		return false;
 	}
-};
+}
 const char *DoubleValueExtractor::gettypename()
 {
 	return "double";
 }
 
+unsigned int DoubleValueExtractor::gettypeID()
+{
+	return double_ty;
+}
 
 
 
@@ -86,13 +97,21 @@ const char *CharacterValueExtractor::gettypename()
 	return "character";
 }
 
-
+unsigned int CharacterValueExtractor::gettypeID()
+{
+	return char_ty;
+}
 
 const char *BoolBaseExtractor::gettypename()
 {
 	return "boolean";
 }
- 
+
+unsigned int BoolBaseExtractor::gettypeID()
+{
+	return bool_ty;
+}
+
 bool BoolInvertingExtractor::getvalue(const char *UNUSEDARG(optname),
 									  const char *UNUSEDARG(instring), unsigned int &UNUSEDARG(currentarg),
 									  bool &result)
@@ -118,21 +137,35 @@ bool BoolTrueExtractor::getvalue(const char *UNUSEDARG(optname), const char *UNU
 }
 
 
-void ProgramOptions::showvalues(ostream & outstr) const
+void ProgramOptions::showvalues(ostream & outstr, bool withdescription ) const
 {
 	for (unsigned int i = 0; i < optcount; i++) {
-		outstr << alloptions[i]->flag << "\t : " << alloptions[i]->gettypename() << "\t : " 
-			<< alloptions[i]->description << "\t : ";
+		(void) outstr.width(20);
+		outstr << alloptions[i]->flag << "\t : " << alloptions[i]->gettypename() << "\t : " ;
+		if (withdescription) outstr	<< alloptions[i]->description << "\t : ";
 		(void)alloptions[i]->writevalue(outstr);
 		outstr << endl;
 	}
 }
 
+void OptionBase::toString(RSString& result) const  {
+		C_ostrstream tempstream;
+		(void)writevalue(tempstream);
+		tempstream << ends;
+#ifdef  USE_NEWSTRSTREAM
+		const string str = tempstream.str();
+		// no freeze / delete needed since ostringstream::str returns a string and not char*
+		result = str.data();
+#else
+		result = tempstream.str();
+		tempstream.rdbuf()->freeze(0);
+#endif
+}
+
 unsigned int ProgramOptions::parseoptions(ostream & outstr, unsigned int argc, const char * const *argv)
 {
 	unsigned int i = 1;					// argv[0] is not of interest
-//	outstr << argc << endl;
-
+	//debug outstr << "parsing options: argc : " << argc << endl;
 	while (i < argc) {
 		bool found = false;
 		for (unsigned int j = 0; j < optcount; j++) {
@@ -153,7 +186,7 @@ unsigned int ProgramOptions::parseoptions(ostream & outstr, unsigned int argc, c
 				outstr << "unknown option " << argv[i] << endl;
 			} else {
 				unhandledOptions[unhandledCounter] = argv[i];
-				unhandledCounter++;
+				++unhandledCounter;
 			}
 		}
 		i++;
@@ -161,16 +194,74 @@ unsigned int ProgramOptions::parseoptions(ostream & outstr, unsigned int argc, c
 	return unhandledCounter;
 }
 
-void ProgramOptions::showhelp(ostream & outstr) const
+static void TeXescapedOutput(ostream & outstr, const char * const st)
 {
-	for (unsigned int i = 0; i < optcount; i++) {
-		if (alloptions[i]->optional) outstr << "[";
-		(void) outstr.width(20) ; outstr << alloptions[i]->flag << "\t : " << alloptions[i]->gettypename() << "\t : " << alloptions[i]->description   ;
-		if (alloptions[i]->optional) outstr << "]";
-		outstr << endl;
+	const char * s = st;
+	while (s && *s) {
+		switch (*s ) {
+			case '[' : outstr << "\\Lbr"; break;
+			case ']' : outstr << "\\Rbr"; break;
+			default: outstr << *s; break;
+		}
+		s++;
 	}
 }
 
+void ProgramOptions::showhelp(ostream & outstr, bool forTeX, bool withdescription, int sheet) const
+{
+	if (optcount && forTeX && withdescription) {
+		outstr << "\\begin{description}" << endl;
+	}
+	const char * const terminator = withdescription ? "] " : " ";
+	for (unsigned int i = 0; i < optcount; i++) {
+		if (forTeX) {
+			if ( ((alloptions[i]->propsheet != 9999) && (sheet == -1)) ||
+					(alloptions[i]->propsheet == sheet))
+			{ // 9999 means hidden
+			if (withdescription) outstr << "\\item["  ;
+			if (alloptions[i]->gettypeID() == bool_ty) {
+				if (alloptions[i]->optional) outstr << "\\oOpt{"; else outstr << "\\Opt{";
+				TeXescapedOutput(outstr,alloptions[i]->flag);
+				outstr << "}" << terminator <<  endl;
+			} else {
+				if (alloptions[i]->optional) outstr << "\\oOptArg{"; else outstr << "\\OptArg{";
+				TeXescapedOutput(outstr,alloptions[i]->flag);
+				outstr << "}" ;
+				const char * aname = alloptions[i]->argname ? alloptions[i]->argname : "missing arg name";
+				outstr << "{~";
+				TeXescapedOutput(outstr,aname);
+				outstr << "}" << terminator<< endl;				
+			}
+			if (withdescription) {
+			const char * help = alloptions[i]->TeXhelp ? alloptions[i]->TeXhelp : alloptions[i]->description;
+			outstr << help << endl << endl;
+			}
+#if 0
+			(void) outstr.width(20) ; outstr << alloptions[i]->flag << "\t : " << alloptions[i]->gettypename() << "\t : " << alloptions[i]->description   ;
+			if (alloptions[i]->optional) outstr << "]";
+#endif
+			if (withdescription) outstr << endl;
+			}
+
+		} else {
+			if (alloptions[i]->optional) outstr << "[";
+			(void) outstr.width(20) ; outstr << alloptions[i]->flag << "\t : " << alloptions[i]->gettypename() << "\t : " << alloptions[i]->description   ;
+			if (alloptions[i]->optional) outstr << "]";
+			outstr << endl;
+		}
+	}
+
+	if (forTeX && withdescription) {
+		if (optcount) {
+			outstr << "\\end{description}" << endl;
+		} else {
+			// this happens only in the context of driver options
+			outstr << "No driver specific options" << endl;
+		}
+	}
+
+}
+
 void ProgramOptions::dumpunhandled(ostream & outstr) const
 {
 	if (unhandledCounter) {
@@ -183,9 +274,9 @@ void ProgramOptions::dumpunhandled(ostream & outstr) const
 	}
 }
 
-void ProgramOptions::add(OptionBase * op)
+void ProgramOptions::add(OptionBase * op, const char * const membername_p)
 {
-	alloptions[optcount] = op;
-	optcount++;
+	alloptions[optcount]   = op;
+	op->membername = membername_p;
+	alloptions[++optcount] = 0;
 }
- 
