@@ -4,7 +4,7 @@
    psfront.h : This file is part of pstoedit
    contains the class responsible for reading the dumped PostScript format
   
-   Copyright (C) 1993 - 2003 Wolfgang Glunz, wglunz@pstoedit.net
+   Copyright (C) 1993 - 2005 Wolfgang Glunz, wglunz34_AT_pstoedit.net
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -40,14 +40,13 @@ class PSFrontEnd {
 public:
 	PSFrontEnd(ostream & outfile_p, 
 			ostream & errstream,
-			const char * infilename_p,
-			const char * outfilename_p, 
-			const float scalefactor_p,
 			const PsToEditOptions & globaloptions_p,
-			const DriverDescription * driverDesc, 
-			const char * driveroptions_p,
-			const bool splitpages_p, 
-			drvbase * backend_p);
+			const char * infilename_p = 0,
+			const char * outfilename_p = 0, 
+			const DriverDescription * driverDesc = 0, 
+			const char * driveroptions_p = 0,
+			const bool splitpages_p = false, 
+			drvbase * backend_p = 0);
 	~PSFrontEnd();
 
 	void 		run(bool merge);	// do the conversion
@@ -62,11 +61,11 @@ private:
 
 	float           popUnScaled(); // pops and returns last value on stack
 
-	void		pstack() const; // for debugging
+	void			pstack() const; // for debugging
 
-	int 		yylex();    // read the input and call the backend specific
+	int 			yylex();    // read the input and call the backend specific
 				    // functions
-	void 		yylexcleanup(); // called from destructor
+	static void 		yylexcleanup(); // called from destructor
 
 
 private:
@@ -74,7 +73,6 @@ private:
 	ostream &	errf;           // the error stream
 	const char * infilename;	
 	const char * outfilename;
-	const float scalefactor;
 	const PsToEditOptions & globaloptions;
 	const DriverDescription * driverDesc;
 	const char * driveroptions;
@@ -92,6 +90,7 @@ private:
 
 	// Inhibitors (declared, but not defined)
 	PSFrontEnd(const PSFrontEnd &);
+	PSFrontEnd();
 	PSFrontEnd & operator=(const PSFrontEnd&);
 };
 
@@ -100,4 +99,3 @@ private:
  
  
  
- 
